@@ -6,13 +6,19 @@ MOONMINING_COMPLETED_EXTRACTIONS_HOURS_UNTIL_STALE = clean_setting(
     "MOONMINING_COMPLETED_EXTRACTIONS_HOURS_UNTIL_STALE", 12
 )
 
-# Reprocessing yield used for calculating all values
-MOONMINING_REPROCESSING_YIELD = clean_setting("MOONMINING_REPROCESSING_YIELD", 0.82)
+# Reprocessing yield used for calculating reprocess prices
+MOONMINING_REPROCESSING_YIELD = clean_setting("MOONMINING_REPROCESSING_YIELD", 0.85)
+
+# Whether to calculate prices from reprocessed materials or not.
+# Will use direct ore prices when switched off
+MOONMINING_USE_REPROCESS_PRICING = clean_setting(
+    "MOONMINING_USE_REPROCESS_PRICING", False
+)
 
 # Total ore volume per month (30.4 days) used for calculating moon values.
 MOONMINING_VOLUME_PER_MONTH = clean_setting("MOONMINING_VOLUME_PER_MONTH", 26345694)
 
-# whether admins will get notifications about import events like
+# whether admins will get notifications about important events like
 # when someone adds a structure owner
 MOONMINING_ADMIN_NOTIFICATIONS_ENABLED = clean_setting(
     "STRUCTURES_ADMIN_NOTIFICATIONS_ENABLED", True
